==> 4.5.0.tar.gz: terraform-provider-decort/internal/service/cloudbroker/pcidevice/resource_check_input_vales.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package pcidevice

import (
	"context"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/compute"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/rg"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func existStackID(ctx context.Context, d *schema.ResourceData, m interface{}) (bool, error) {
	c := m.(*controller.ControllerCfg)
	StackID := uint64(d.Get("stack_id").(int))
	RGID := uint64(d.Get("rg_id").(int))

	req := rg.ListRequest{
		IncludeDeleted: false,
	}

	rgList, err := c.CloudBroker().RG().List(ctx, req)
	if err != nil {
		return false, err
	}

	for _, v := range rgList.FilterByID(RGID).Data {
		for _, idVM := range v.VMs {
			req := compute.GetRequest{
				ComputeID: idVM,
			}
			checkStackID, err := c.CloudBroker().Compute().Get(ctx, req)
			if err != nil {
				return false, err
			}
			if checkStackID.StackID == StackID {
				return true, nil
			}
		}
	}

	return false, err
}

func existRGID(ctx context.Context, d *schema.ResourceData, m interface{}) (bool, error) {
	c := m.(*controller.ControllerCfg)
	RGID := uint64(d.Get("rg_id").(int))
	req := rg.ListRequest{
		IncludeDeleted: false,
	}

	rgList, err := c.CloudBroker().RG().List(ctx, req)
	if err != nil {
		return false, err
	}

	return len(rgList.FilterByID(RGID).Data) != 0, nil
}

==> 4.9.0.tar.gz: terraform-provider-decort/internal/service/cloudbroker/pcidevice/resource_check_input_vales.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package pcidevice

import (
	"context"

	"github.com/hashicorp/terraform-plugin-sdk/v2/diag"
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/dc"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/ic"
)

func checkParamsExistence(ctx context.Context, d *schema.ResourceData, c *controller.ControllerCfg) diag.Diagnostics {
	var errs []error

	stackId := uint64(d.Get("stack_id").(int))
	rgId := uint64(d.Get("rg_id").(int))

	if err := ic.ExistRG(ctx, rgId, c); err != nil {
		errs = append(errs, err)
	}

	if err := ic.ExistStack(ctx, stackId, c); err != nil {
		errs = append(errs, err)
	}

	return dc.ErrorsToDiagnostics(errs)
}
